# remirepo spec file for php-pecl-oauth
# with SCL compatibility, from Fedora:
#
# Fedora spec file for php-pecl-oauth
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please, preserve the changelog entries
#

%bcond_without     tests

%{?scl:%scl_package php-pecl-oauth}

%global pecl_name   oauth
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure ../%{sources}/configure

Name:           %{?scl_prefix}php-pecl-oauth
Version:        2.0.7
Release:        11%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Summary:        PHP OAuth consumer extension
License:        BSD-3-Clause
URL:            https://pecl.php.net/package/oauth
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

Patch0:         %{pecl_name}-pcre.patch
Patch1:         %{pecl_name}-php82.patch
Patch2:         %{pecl_name}-php84.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-posix
BuildRequires:  pcre-devel
BuildRequires:  libcurl-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
OAuth is an authorization protocol built on top of HTTP which allows 
applications to securely access data without having to store
user names and passwords.

Documentation: http://php.net/oauth

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1 -b .up
%patch -P1 -p1 -b .pr24
%patch -P2 -p1 -b .pr30

#sed -e '/PHP_OAUTH_VERSION/s/2.0.3-dev/2.0.3/' -i php_oauth.h
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_OAUTH_VERSION/{s/.* //;s/".*$//;p}' php_oauth.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

cat >%{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure --with-php-config=%{__phpconfig}
%make_build

%if %{with_zts}
cd ../ZTS
%configure --with-php-config=%{__ztsphpconfig}
%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# Drop in the bit of configuration
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} -n \
    -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^OAuth$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=posix.so -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} -n \
    -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^OAuth$'

%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Sep 30 2024 Remi Collet <remi@remirepo.net> - 2.0.7-11
- more patch for 8.4

* Tue Jul  9 2024 Remi Collet <remi@remirepo.net> - 2.0.7-10
- add patch for PHP 8.4 from
  https://github.com/php/pecl-web_services-oauth/pull/30

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 2.0.7-9
- rebuild for PHP 8.3.0RC1

* Tue Jul 18 2023 Remi Collet <remi@remirepo.net> - 2.0.7-8
- build out of sources tree

* Tue Sep 20 2022 Remi Collet <remi@remirepo.net> - 2.0.7-7
- drop unneeded build dependency on pcre #2128353

* Fri Sep  9 2022 Remi Collet <remi@remirepo.net> - 2.0.7-6
- add patch for PHP 8.2 from
  https://github.com/php/pecl-web_services-oauth/pull/24

* Mon Sep  6 2021 Remi Collet <remi@remirepo.net> - 2.0.7-5
- re-build

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 2.0.7-2
- rebuild for PHP 8.0.0RC1

* Fri Sep 18 2020 Remi Collet <remi@remirepo.net> - 2.0.7-1
- update to 2.0.7
- drop patch merged upstream

* Fri Sep 18 2020 Remi Collet <remi@remirepo.net> - 2.0.6-3
- more fixes for PHP 8

* Thu Sep 10 2020 Remi Collet <remi@remirepo.net> - 2.0.6-2
- add fix for PHP 8 from
  https://github.com/php/pecl-web_services-oauth/pull/16
- enable test suite

* Wed Sep  9 2020 Remi Collet <remi@remirepo.net> - 2.0.6-1
- update to 2.0.6

* Thu Feb  6 2020 Remi Collet <remi@remirepo.net> - 2.0.5-1
- update to 2.0.5

* Mon Dec  2 2019 Remi Collet <remi@remirepo.net> - 2.0.4-1
- update to 2.0.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.3-6
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.0.3-5
- rebuild for 7.4.0beta1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 2.0.3-4
- rebuild

* Thu May 23 2019 Remi Collet <remi@remirepo.net> - 2.0.3-3
- add upstream patch for 7.4

* Fri Mar  1 2019 Remi Collet <remi@remirepo.net> - 2.0.3-2
- rebuild

* Mon Oct  1 2018 Remi Collet <remi@remirepo.net> - 2.0.3-1
- update to 2.0.3

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.0.2-7
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.0.2-6
- rebuild for 7.3.0alpha4 new ABI

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 2.0.2-5
- add upstream patches for PHP 7.3

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.2-4
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.0.2-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.0.2-2
- rebuild for PHP 7.1 new API version

* Mon Jun 20 2016 Remi Collet <rcollet@redhat.com> - 2.0.2-1
- update to 2.0.2

* Fri Mar 11 2016 Remi Collet <rcollet@redhat.com> - 2.0.1-1
- update to 2.0.1

* Sun Mar  6 2016 Remi Collet <rcollet@redhat.com> - 2.0.0-2
- adapt for F24

* Sun Jan  3 2016 Remi Collet <rcollet@redhat.com> - 2.0.0-1
- update to 2.0.0 (php 7, stable)

* Tue Jun 23 2015 Remi Collet <rcollet@redhat.com> - 1.2.3-10
- allow build against rh-php56 (as more-php56)

* Fri Jan 23 2015 Remi Collet <remi@fedoraproject.org> - 1.2.3-9
- fix %%postun scriplet

* Thu Jan 22 2015 Remi Collet <remi@fedoraproject.org> - 1.2.3-8
- bump release
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.2.3-7.1
- Fedora 21 SCL mass rebuild

* Mon Aug 25 2014 Remi Collet <rcollet@redhat.com> - 1.2.3-7
- improve SCL build

* Wed Apr 16 2014 Remi Collet <remi@fedoraproject.org> - 1.2.3-6
- add numerical prefix to extension configuration file (php 5.6)

* Wed Mar 19 2014 Remi Collet <rcollet@redhat.com> - 1.2.3-5
- allow SCL build

* Wed Mar 12 2014 Remi Collet <remi@fedoraproject.org> - 1.2.3-4
- cleanups
- move doc in pecl_docdir

* Fri Nov 30 2012 Remi Collet <remi@fedoraproject.org> - 1.2.3-1.1
- also provides php-oauth

* Tue Oct  2 2012 Remi Collet <remi@fedoraproject.org> - 1.2.3-1
- update to 1.2.3

* Tue Sep  4 2012 Remi Collet <remi@fedoraproject.org> - 1.2.2-4
- EL rebuild

* Sun Nov 13 2011 Remi Collet <remi@fedoraproject.org> - 1.2.2-3
- build against php 5.4

* Tue Oct 04 2011 Remi Collet <RPMS@FamilleCollet.com> - 1.2.2-2
- ZTS extension

* Fri Jul 22 2011 Remi Collet <RPMS@FamilleCollet.com> - 1.2.2-1
- update to 1.2.2

* Fri Jul 22 2011 Remi Collet <RPMS@FamilleCollet.com> - 1.2.1-1
- rebuild for remi repo

* Fri Jul 22 2011 F. Kooman <fkooman@tuxed.net> - 1.2.1-1
- update to 1.2.1 (RHBZ #724872). See
  https://pecl.php.net/package-changelog.php?package=oauth&release=1.2.1

* Mon Jul 04 2011 Remi Collet <RPMS@FamilleCollet.com> - 1.2-1
- rebuild for remi repo

* Sun Jul 03 2011 F. Kooman <fkooman@tuxed.net> - 1.2-1
- upgrade to 1.2

* Sat Jun 25 2011 Remi Collet <RPMS@FamilleCollet.com> - 1.1.0-6
- rebuild for remi repo

* Sun Jun 19 2011 F. Kooman <fkooman@tuxed.net> - 1.1.0-6
- add fix for https://pecl.php.net/bugs/bug.php?id=22337

* Tue Jun 14 2011 Remi Collet <RPMS@FamilleCollet.com> - 1.1.0-5
- rebuild for remi repo

* Mon Jun 13 2011 F. Kooman <fkooman@tuxed.net> - 1.1.0-5
- remove php_apiver marco, was not used

* Mon Jun 13 2011 F. Kooman <fkooman@tuxed.net> - 1.1.0-4
- add minimal check to see if module loads
- fix private-shared-object-provides rpmlint warning

* Sat Jun 11 2011 F. Kooman - 1.1.0-3
- BR pcre-devel

* Sat May 28 2011 F. Kooman - 1.1.0-2
- require libcurl for cURL request engine support 

* Sat May 28 2011 F. Kooman - 1.1.0-1
- initial package 
